import os
from pathlib import Path
from typing import List

class Filestore:

    def __init__(self, path_dir: str) -> None:
        self.path_dir = path_dir

    def get_path_file(self, key) -> str:
        return os.path.join(self.path_dir, key)

    def exists(self, key) -> bool:
        return self.path.is_file(self.get_path_file(key))



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

with open("requirements.txt", "r") as f:
    requirements = f.read().splitlines()

setup(
    name="srai-core",
    packages=find_packages(),
    version="0.3.0",
    license='MIT',
    package_data={},
    python_requires=">=3.5",
    install_requires=requirements,
    author="Jaap Oosterbroek",
    author_email="jaap.oosterbroek@southriverai.com",
    description="A library core functions used in other SRAI libraries.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/southriverai/srai-core",
    download_url='https://github.com/southriverai/srai-core/archive/v_01.tar.gz',
    keywords=['SRAI', 'TOOLS'],
    classifiers=[
        'Development Status :: 3 - Alpha', 
        'Intended Audience :: Developers',      # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
    ],
)



